import java.io.File;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.ArrayList;
import java.util.Locale;
import java.util.Scanner;

public class aerodynamics_dg_tl_nm implements Runnable {
	
	class Point {
		double x, y;
		
		public Point(double x, double y) {
			this.x = x;
			this.y = y;
		}
	}
	
	final static double eps = 1e-9;

	protected double vect(Point origin1, Point p1, Point origin2, Point p2) {
		return (p1.x - origin1.x) * (p2.y - origin2.y) - (p1.y - origin1.y) * (p2.x - origin2.x);
	}

	protected double scalar(Point origin1, Point p1, Point origin2, Point p2) {
		return (p1.x - origin1.x) * (p2.x - origin2.x) + (p1.y - origin1.y) * (p2.y - origin2.y);
	}

	private void solve() throws IOException {
		Scanner sc = new Scanner(new File("aerodynamics.in"));
		PrintWriter pw = new PrintWriter("aerodynamics.out");
		
		int n = sc.nextInt();
		int zmin = sc.nextInt();
		int zmax = sc.nextInt();
		int[] x = new int[n];
		int[] y = new int[n];
		int[] z = new int[n];
		for (int i = 0; i < n; i++) {
			x[i] = sc.nextInt();
			y[i] = sc.nextInt();
			z[i] = sc.nextInt();
		}

		assert 4 <= n && n <= 100 : "wrong n: " + n;
		assert 0 <= zmin && zmin <= zmax && zmax <= 100 : "wrong zmin or zmax: " + zmin + " " + zmax;
		boolean foundPlane = false;
		long planeX = 0, planeY = 0, planeZ = 0;
		for (int i = 0; i < n; i++) {
			assert Math.abs(x[i]) <= 1000 && Math.abs(y[i]) <= 1000 && Math.abs(z[i]) <= 1000 : "wrong coordinates of " + (i + 1) + " point: " + x[i] + " " + y[i] + " " + z[i];
			for (int j = i + 1; j < n; j++) {
				assert x[i] != x[j] || y[i] != y[j] || z[i] != z[j] : "points " + (i + 1) + " and " + (j + 1) + " coincide: " + x[i] + " " + y[i] + " " + z[i];
				if (!foundPlane) {
					for (int k = j + 1; k < n; k++) {
						planeX = (y[j] - y[i]) * (z[k] - z[i]) - (y[k] - y[i]) * (z[j] - z[i]);
						planeY = -((x[j] - x[i]) * (z[k] - z[i]) - (x[k] - x[i]) * (z[j] - z[i]));
						planeZ = (x[j] - x[i]) * (y[k] - y[i]) - (x[k] - x[i]) * (y[j] - y[i]);
						if (planeX != 0 || planeY != 0 || planeZ != 0) {
							foundPlane = true;
							break;
						}
					}
				}
			}
		}
		assert foundPlane : "plane not found - all points belong the same line";
		boolean foundNotInPlane = false;
		for (int i = 0; i < n; i++) {
			foundNotInPlane |= (planeX * x[i] + planeY * y[i] + planeZ * z[i] != 0);
		}
		assert foundNotInPlane : "all points belong the same plane, normal vector: " + planeX + " " + planeY + " " + planeZ;
		
		for (int zcur = zmin; zcur <= zmax; zcur++) {
			ArrayList<Point> points = new ArrayList<Point>();
			
			for (int i = 0; i < n; i++) {
				if (z[i] == zcur) {
					points.add(new Point(x[i], y[i]));
				}
			}
			
			for (int i = 0; i < n; i++) {
				for (int j = 0; j < n; j++) {
					if (z[i] < zcur && z[j] > zcur) {
						double t = 1.0 * (zcur - z[i]) / (z[j] - z[i]);
						points.add(new Point(x[i] + t * (x[j] - x[i]), y[i] + t * (y[j] - y[i])));
					}
				}
			}
			
			if (points.size() < 3) {
				pw.printf("%.10f\n", 0.0);
				continue;
			}
			
			ArrayList<Point> stack = new ArrayList<Point>();
			Point origin = points.get(0);
			for (Point p : points) {
				if (p.y < origin.y || p.y < origin.y + eps && p.x < origin.x) {
					origin = p;
				}
			}
			
			stack.add(origin);
			Point current = origin;
			Point previous = new Point(current.x - 3000, current.y + 1);
			while (true) {
				Point next = null;
				double ncos = 0;
				double ndist = 0;
				for (Point p : points) {
					if (vect(current, previous, p, current) < eps) {
						continue;
					}
					double dist = Math.hypot(p.x - current.x, p.y - current.y);
					double cos = scalar(current, previous, p, current) / dist;
					if (next == null || cos > ncos + eps || Math.abs(cos - ncos) < eps && dist > ndist + eps) {
						next = p;
						ncos = cos;
						ndist = dist;
					}
				}
				if (next == null || next == origin) {
					break;
				}
				stack.add(next);
				previous = current;
				current = next;
			}
			
			double area = 0;
			stack.add(origin);
			for (int i = 0; i < stack.size() - 1; i++) {
				Point p1 = stack.get(i);
				Point p2 = stack.get(i + 1);
				area += p1.x * p2.y - p1.y * p2.x;
			}
			
			pw.printf("%.10f\n", Math.abs(area) / 2);
		}
		
		sc.close();
		pw.close();
	}

	public static void main(String[] args) {
		Locale.setDefault(Locale.US);
		new Thread(new aerodynamics_dg_tl_nm()).start();
	}

	public void run() {
		try {
			solve();
		} catch (IOException e) {
			e.printStackTrace();
		}
	}
	
}
