import java.io.BufferedReader;
import java.io.FileReader;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.ArrayList;
import java.util.List;

public class aerodynamics_petr {
    private static final int MAX_N = 100;
    private static final int MAX_Z = 100;
    private static final int MAX_COORD = 1000;

    private static class Rational implements Comparable<Rational> {
        public final long p;
        public final long q;

        public Rational(long p, long q) {
            this.p = p;                                               
            this.q = q;
            if (q < 0)
                throw new RuntimeException();
        }

        public Rational(long x) {
            this(x, 1);
        }

        public Rational subtract(Rational o) {
            if (q == o.q)
                return new Rational(p - o.p, q);
            else
                return new Rational(p * o.q - q * o.p, q * o.q);
        }

        public Rational multiply(Rational o) {
            return new Rational(p * o.p, q * o.q);
        }

        public Rational add(Rational o) {
            if (q == o.q)
                return new Rational(p + o.p, q);
            else
                return new Rational(p * o.q + q * o.p, q * o.q);
        }

        public int signum() {
            if (p > 0)
                return 1;
            else if (p < 0)
                return -1;
            else
                return 0;
        }

        public Rational abs() {
            return new Rational(Math.abs(p), q);
        }

        public double doubleValue() {
            return p / (double) q;
        }

        public int compareTo(Rational o) {
            return subtract(o).signum();
        }

        @Override
        public String toString() {
            return p + "/" + q;
        }
    }

    private static class Point {
        public final Rational x;
        public final Rational y;

        Point(Rational x, Rational y) {
            this.x = x;
            this.y = y;
        }
    }

    public static void main(String[] args) throws IOException {
        BufferedReader reader = new BufferedReader(new FileReader("aerodynamics.in"));
        String[] parts = reader.readLine().split(" ", -1);
        if (parts.length != 3)
            throw new RuntimeException();
        int n = Integer.parseInt(parts[0]);
        if (n < 4 || n > MAX_N)
            throw new RuntimeException();
        int zMin = Integer.parseInt(parts[1]);
        if (zMin < 0 || zMin > MAX_Z)
            throw new RuntimeException();
        int zMax = Integer.parseInt(parts[2]);
        if (zMax < zMin || zMax > MAX_Z)
            throw new RuntimeException();
        int[] x = new int[n];
        int[] y = new int[n];
        int[] z = new int[n];
        for (int i = 0; i < n; ++i) {
            parts = reader.readLine().split(" ", -1);
            if (parts.length != 3)
                throw new RuntimeException();
            x[i] = Integer.parseInt(parts[0]);
            y[i] = Integer.parseInt(parts[1]);
            z[i] = Integer.parseInt(parts[2]);
            if (x[i] < -MAX_COORD || x[i] > MAX_COORD)
                throw new RuntimeException();
            if (y[i] < -MAX_COORD || y[i] > MAX_COORD)
                throw new RuntimeException();
            if (z[i] < -MAX_COORD || z[i] > MAX_COORD)
                throw new RuntimeException();
        }
        if (reader.read() != -1)
            throw new RuntimeException();
        for (int i = 0; i < n; ++i)
            for (int j = i + 1; j < n; ++j)
                if (x[i] == x[j] && y[i] == y[j] && z[i] == z[j])
                    throw new RuntimeException();
        if (allOnOnePlane(n, x, y, z))
            throw new RuntimeException();

        PrintWriter writer = new PrintWriter("aerodynamics.out");
        for (int cz = zMin; cz <= zMax; ++cz) {
            List<Point> cList = new ArrayList<Point>();
            for (int i = 0; i < n; ++i) {
                if (z[i] == cz)
                    cList.add(new Point(new Rational(x[i]), new Rational(y[i])));
                if (z[i] < cz)
                    for (int j = 0; j < n; ++j)
                        if (z[j] > cz) {
                            cList.add(new Point(
                                    new Rational(x[i] * (z[j] - z[i]) + (x[j] - x[i]) * (cz - z[i]), (z[j] - z[i])),
                                    new Rational(y[i] * (z[j] - z[i]) + (y[j] - y[i]) * (cz - z[i]), (z[j] - z[i]))));
                        }
            }
            /*System.out.println(cz);
            for (int i = 0; i < cList.size(); ++i) {
                System.out.print("(" + cList.get(i).x + "," + cList.get(i).y + ") ");
            }
            System.out.println("");*/
            writer.println(hullArea(cList));
        }
        writer.close();
    }

    private static boolean allOnOnePlane(int n, int[] x, int[] y, int[] z) {
        for (int i = 1; i < n; ++i)
            for (int j = i + 1; j < n; ++j)
                for (int k = j + 1; k < n; ++k) {
                    if (det(x[i] - x[0], y[i] - y[0], z[i] - z[0], x[j] - x[0], y[j] - y[0], z[j] - z[0], x[k] - x[0], y[k] - y[0], z[k] - z[0]) != 0)
                        return false;
                }
        return true;
    }

    private static long det(long a11, long a12, long a13, long a21, long a22, long a23, long a31, long a32, long a33) {
        return a11 * a22 * a33 + a21 * a32 * a13 + a31 * a12 * a23 - a13 * a22 * a31 - a23 * a32 * a11 - a33 * a12 * a21;
    }

    private static double hullArea(List<Point> points) {
        Point start = null;
        for (Point point : points) {
            if (start == null)
                start = point;
            else {
                int cx = point.x.compareTo(start.x);
                if (cx < 0)
                    start = point;
                else if (cx == 0) {
                    if (point.y.compareTo(start.y) < 0)
                        start = point;
                }
            }
        }
        double res = 0;
        Point cur = start;
        do {
            Point next = null;
            Rational ndx = null;
            Rational ndy = null;
            Rational nlen = null;
            for (Point point : points)
                if (point.x.compareTo(cur.x) != 0 || point.y.compareTo(cur.y) != 0) {
                    Rational dx = point.x.subtract(cur.x);
                    Rational dy = point.y.subtract(cur.y);
                    Rational len = dx.abs().add(dy.abs());
                    if (next != null) {
                        int s = dx.multiply(ndy).subtract(dy.multiply(ndx)).signum();
                        if (s < 0)
                            continue;
                        if (s == 0) {
                            s = len.compareTo(nlen);
                            if (s <= 0)
                                continue;
                        }
                    }
                    ndx = dx;
                    ndy = dy;
                    next = point;
                    nlen = len;
                }
            if (next == null)
                return 0.0;
            res += next.x.add(cur.x).multiply(next.y.subtract(cur.y)).doubleValue();
            cur = next;
        } while (cur.x.compareTo(start.x) != 0 || cur.y.compareTo(start.y) != 0);
        return Math.abs(res) / 2;
    }
}