#pragma comment(linker, "/STACK:256000000")
#define _CRT_SECURE_NO_WARNINGS
#include <cstdio>
#include <iostream>
#include <vector>
#include <algorithm>
#include <string>
#include <queue>
#include <set>
#include <map>
#include <sstream>
#include <cmath>
#include <cassert>
#include <memory.h>

using namespace std;

#define forn(i, n) for (int i = 0; i < int(n); i++)
#define forv(i, v) forn(i, v.size())
#define for1(i, n) for (int i = 1; i <= int(n); i++)

#define all(x) x.begin(), x.end()
#define pb push_back
#define mp make_pair

typedef pair<int, int> pii;
typedef long long ll;
typedef long double ld;

struct Point
{
	int x, y, z;
	Point() {};
	Point(int x, int y, int z): x(x), y(y), z(z) {};
};

struct Plane
{
	ll a, b, c, d;
	vector<int> idx;
};


inline bool operator<(const Point& p1, const Point& p2)
{
	if (p1.x != p2.x) return p1.x < p2.x;
	if (p1.y != p2.y) return p1.y < p2.y;
	return p1.z < p2.z;
}

inline bool operator==(const Point& p1, const Point& p2)
{
	return p1.x == p2.x && p1.y == p2.y && p1.z == p2.z;
}

inline Point operator-(const Point& p1, const Point& p2)
{
	return Point(p1.x - p2.x, p1.y - p2.y, p1.z - p2.z);
}

ll det(int x1, int y1, int x2, int y2)
{
	return x1 * y2 - x2 * y1;
}

ll vol(Point p1, Point p2, Point p3, Point p4)
{
	p1 = p1 - p4;
	p2 = p2 - p4;
	p3 = p3 - p4;

	return p1.x * det(p2.y, p2.z, p3.y, p3.z) - p1.y * det(p2.x, p2.z, p3.x, p3.z) + p1.z * det(p2.x, p2.y, p3.x, p3.y);
}

double dist(Point& p1, Plane& s)
{
	return abs(p1.x * s.a + p1.y * s.b + p1.z * s.c + s.d) / sqrt(s.a*s.a+s.b*s.b+s.c*s.c*1.0);
}

const int NMAX = 300005;
int n;
Point p[NMAX];
bool usp[NMAX];

Point center;

int m = 0;
Plane sides[NMAX];
vector<int> plist[NMAX];
set<int> alive_sides;

void addTriangle(int i1, int i2, int i3)
{
	Point p1 = p[i1]; 
	Point p2 = p[i2]; 
	Point p3 = p[i3];

	Plane s;

	s.a = det(p1.y - p2.y, p3.y - p1.y, p1.z - p2.z, p3.z - p1.z);
	s.b = det(p1.z - p2.z, p3.z - p1.z, p1.x - p2.x, p3.x - p1.x);
	s.c = det(p1.x - p2.x, p3.x - p1.x, p1.y - p2.y, p3.y - p1.y);
	s.d = -(s.a * p1.x + s.b * p1.y + s.c * p1.z);
	
	s.idx = vector<int>(3);
	s.idx[0] = i1; s.idx[1] = i2; s.idx[2] = i3;

	sort(all(s.idx));

 	if (s.a * center.x + s.b * center.y + s.c * center.z + 4 * s.d < 0)
 	{
 		s.a = -s.a;
 		s.b = -s.b;
 		s.c = -s.c;
 		s.d = -s.d;
 	}
 		
  	alive_sides.insert(m);
	sides[m++] = s;	
	assert(m < NMAX);
}


bool can_see(Point& p, Plane& s)
{
	return s.a * p.x + s.b * p.y + s.c * p.z + s.d < 0;
}
void addPointToList(int id)
{
	Point q = p[id];

	forn(i, m)
	{
		if (can_see(q, sides[i]))
		{
			plist[i].pb(id);
			break;
		}
	}
}


void process(int sid)
{
	Plane s = sides[sid];

	if (plist[sid].empty()) return;

	double max_dist = 0;
	int best = -1;

	forv(i, plist[sid])
	{
		Point q = p[plist[sid][i]];
		if (dist(q, s) > max_dist)
		{
			max_dist = dist(q, s);
			best = plist[sid][i];
		}
	}

	vector<int> alive(all(alive_sides));
	vector<pii> erased_edges;
	vector<int> points;

	forv(i, alive)
	{
		if (can_see(p[best], sides[alive[i]]))
		{
			alive_sides.erase(alive[i]);
			forn(i1, 3)
				forn(i2, i1)
					erased_edges.pb(mp(sides[alive[i]].idx[i2], sides[alive[i]].idx[i1]));
			forv(j, plist[alive[i]])
				points.pb(plist[alive[i]][j]);
			plist[alive[i]].clear();		
		}
	}

	sort(all(erased_edges));

	forv(i, erased_edges)
	{
		if (i == (int)erased_edges.size() - 1 || erased_edges[i] != erased_edges[i + 1])
		{
			addTriangle(erased_edges[i].first, erased_edges[i].second, best);
			vector<int> npoints;
			forv(j, points)
			{
				if (can_see(p[points[j]], sides[m - 1]))
					plist[m - 1].pb(points[j]);
				else
					npoints.pb(points[j]);
			}
			points = npoints;
		}	
		else i++;
	}    
}

int findMinX()
{
	int best = 0;
	forn(i, n)
		if (p[i].x < p[best].x) best = i;
	return best;
}
int findMinY()
{
	int best = 0;
	forn(i, n)
		if (p[i].y < p[best].y) best = i;
	return best;
}
int findMinZ()
{
	int best = 0;
	forn(i, n)
		if (p[i].z < p[best].z) best = i;
	return best;
}
int findMaxX()
{
	int best = 0;
	forn(i, n)
		if (p[i].x > p[best].x) best = i;
	return best;
}
int findMaxY()
{
	int best = 0;
	forn(i, n)
		if (p[i].y > p[best].y) best = i;
	return best;
}
int findMaxZ()
{
	int best = 0;
	forn(i, n)
		if (p[i].z > p[best].z) best = i;
	return best;
}

bool check()
{
	vector<int> alive(all(alive_sides));

	forv(i, alive)
	{
		forn(i, n)
			if (can_see(p[i], sides[alive[i]]))
				return false;
	}

	return true;
}
int main()
{
    freopen("input.txt", "rt", stdin);
    freopen("output.txt", "wt", stdout);

    cin >> n;
    forn(i, n) cin >> p[i].x >> p[i].y >> p[i].z;

    sort(p, p + n);
    n = int(unique(p, p + n) - p);

    assert(n >= 4);

    vector<int> temp;
    temp.pb(findMinX());
    temp.pb(findMaxX());
    temp.pb(findMinY());
    temp.pb(findMaxY());
    temp.pb(findMinZ());
    temp.pb(findMaxZ());

    sort(all(temp));
    temp.erase(unique(all(temp)), temp.end());
    assert(temp.size() >= 4);
    int i1 = temp[0];
    int i2 = temp[1];
    int i3 = temp[2];
    int i4 = temp[3];

    usp[i1] = usp[i2] = usp[i3] = usp[i4] = true;

    center.x = p[i1].x + p[i2].x + p[i3].x + p[i4].x;
    center.y = p[i1].y + p[i2].y + p[i3].y + p[i4].y;
    center.z = p[i1].z + p[i2].z + p[i3].z + p[i4].z;

    addTriangle(i1, i2, i3);
    addTriangle(i1, i2, i4);
    addTriangle(i2, i3, i4);
    addTriangle(i1, i3, i4);

    forn(i, n)
    {
    	if (usp[i]) continue;
    	addPointToList(i);
    }

    forn(i, m)
    {
    	if (alive_sides.count(i) == 0) continue;
    	process(i);
    }

    ll V = 0;
    forn(i, m)
    {
    	if (alive_sides.count(i))
    		V += abs(vol(p[0], p[sides[i].idx[0]], p[sides[i].idx[1]], p[sides[i].idx[2]]));
    }

     
    cout << V << endl;

//	cout << alive_sides.size() << endl;

//	cout << check() << endl;

    return 0;
}