#include <bits/stdc++.h>

using namespace std;

typedef long long ll;
typedef long double ld;

#define sz(x) ((int) (x).size())
#define pb push_back
#define mp make_pair
#define fi first
#define se second

#define NAME "b"

struct pt
{
	ld x, y, z;
	
	pt(ld nx = 0, ld ny = 0, ld nz = 0): x(nx), y(ny), z(nz) {}
	
	ld operator*(const pt &a) const
	{
		return x * a.x + y * a.y + z * a.z;
	}
	
	pt operator%(const pt &p) const
	{
		return pt(y * p.z - z * p.y, 
				  z * p.x - x * p.z,
				  x * p.y - y * p.x);
	}
	
	pt operator - (const pt &p) const
	{
		return pt(x - p.x, y - p.y, z - p.z);
	}
	
	pt operator + (const pt &p) const
	{
		return pt(x + p.x, y + p.y, z + p.z);
	}
	
	pt operator / (const ld k) const
	{
		return pt(x / k, y / k, z / k);
	}
	
	pt operator * (const ld k) const
	{
		return pt(k * x, k * y, k * z);
	}
	
	ld operator ~() const
	{
		return sqrtl((*this) * (*this));
	}
	
	ld sqlen() const
	{
		return *this * *this;
	}
};

const int maxn = 110;

int n;
pt pts[maxn];

const ld eps = 1e-9;

ld sq(pt a, pt b, pt c)
{
	return ~((b - a) % (c - a));
}

bool intriang(pt p, pt a, pt b, pt c)
{
	return fabsl(sq(p, a, b) + sq(p, b, c) + sq(p, c, a) - sq(a, b, c)) < eps;
}

ld dist(pt p, pt a, pt b, pt c)
{
	ld ans = ~(p - a);
	ans = min(ans, ~(p - b));
	ans = min(ans, ~(p - c));
	pt norm = (b - a) % (c - a);
	pt proj = p - norm * ((p - a) * norm / norm.sqlen());
	if (intriang(proj, a, b, c))
		ans = min(ans, ~(p - proj));
	return ans;
}

int good[maxn][maxn][maxn];
vector<int> face;

struct cmpTurn
{
	pt norm;
	
	cmpTurn(const pt &nn): norm(nn) {}
	
	bool operator () (int i, int j) const
	{
		return (pts[i] % pts[j]) * norm < -eps;
	}
};

bool facet(int x, int y, int z)
{
	if (good[x][y][z] != -1) return good[x][y][z];
	pt o = pts[z];
	for (int i = 0; i < n; ++i)
		pts[i] = pts[i] - o;

	pt norm = pts[x] % pts[y];
	bool neg = false, pos = false;
	face.clear();
	for (int i = 0; i < n; ++i)
	{
		ld q = pts[i] * norm;
		if (q < -eps) neg = true;
		else if (q > eps) pos = true;
		else if (i != z) face.pb(i);
	}
	if (!neg || !pos)
	{
		//cerr << x << " " << y << " " << z << endl;
		face.pb(z);
		for (int f1 : face)
			for (int f2 : face)
				for (int f3 : face)
					good[f1][f2][f3] = 0;
		face.pop_back();

		sort(face.begin(), face.end(), cmpTurn(norm));

		for (size_t i = 0; i + 1 < face.size(); ++i)
		{
			int q = face[i], w = face[i + 1];
			//cerr << "Good " << q << " " << w << " " << z << endl;
			good[q][w][z] = 1;
			good[q][z][w] = 1;
			good[w][q][z] = 1;
			good[w][z][q] = 1;
			good[z][w][q] = 1;
			good[w][q][y] = 1;
		}
	}
	else good[x][y][z] = 0;
	for (int i = 0; i < n; ++i)
		pts[i] = pts[i] + o;
	return good[x][y][z];
}

pt centre(int x, int y, int z, int t)
{
	return (pts[x] + pts[y] + pts[z] + pts[t]) / 4.0;
}

ld vol(pt a, pt b, pt c, pt d)
{
	return fabsl(((b - d) % (c - d)) * (a - d));
}

ld calc()
{
	memset(good, -1, sizeof(good));
	ld ans = 1e10;
	pt sumpt = pt();
	ld sumvol = 0;
	vector< pair< pair<int, int>, int> > facets;
	for (int i = 0; i < n; ++i)
		for (int j = i + 1; j < n; ++j)
			for (int z = j + 1; z < n; ++z)
			{
				if (!facet(i, j, z)) continue;
//				cerr << "Face " << i << " " << j << " " << z << endl;
				facets.pb(mp(mp(i, j), z));
				pt c = centre(0, i, j, z);
				ld v = vol(pts[0], pts[i], pts[j], pts[z]);
				sumvol += v;
				sumpt = sumpt + c * v;
			}
	pt c = sumpt / sumvol;
//	cerr << "Centre = " << c.x << " " << c.y << " " << c.z << endl;
	for (auto f : facets)
	{
		int i = f.fi.fi, j = f.fi.se, z = f.se;
		ans = min(ans, dist(c, pts[i], pts[j], pts[z]));
	}
//	cerr << ans << endl;
	return ans;
}

int main()
{
	#ifdef LOCAL
	assert(freopen(NAME ".in", "r", stdin));
	#endif // LOCAL
	ld ans = 0;
	for (int i = 0; i < 2; ++i)
	{
		cin >> n;
		for (int j = 0; j < n; ++j)
			cin >> pts[j].x >> pts[j].y >> pts[j].z;
		ans += calc();
	}
	cout.precision(10);
	cout << fixed << ans << endl;
	#ifdef LOCAL
	cerr << "Time: " << double(clock()) / CLOCKS_PER_SEC << "\n";
	#endif // LOCAL
	return 0;
}
