#include <cstdio>
#include <cstdlib>
#include <cstring>
#include <cassert>

#include <iostream>
#include <iomanip>
#include <string>
#include <vector>
#include <set>
#include <map>
#include <deque>
#include <queue>
#include <stack>
#include <algorithm>
#include <cassert>

#define forn(i, n) for(int i = 0; i < int(n); i++)
#define mp make_pair
#define pb push_back
#define foreach(it, v) for(__typeof(v.begin()) it = v.begin(); it != v.end(); ++it)

using namespace std;

typedef long long ll;

struct Point {
	int x, y, id;

	bool operator < (const Point & other) const {
		if(x != other.x)
			return x < other.x;
		return y < other.y;
	}
	
	bool operator == (const Point & other) const {
		return (x == other.x && y == other.y);
	}
};

struct ConvexCompare {
	const Point & basePoint;
	
	ConvexCompare(const Point & basePoint) : basePoint(basePoint) {}
	
	inline bool operator () (const Point & a, const Point & b) const {
		int ax = a.x - basePoint.x, ay = a.y - basePoint.y;
		int bx = b.x - basePoint.x, by = b.y - basePoint.y;
		int mult = ax * by - ay * bx;
		if(mult != 0) return mult < 0;
		int da = ax * ax + ay * ay;
		int db = bx * bx + by * by;
		return da < db;
	}
};

template < typename T >
bool isSorted(const vector < Point > & allPoints, T compare) {
	int n = allPoints.size();
	for(int i = 1; i < n; i++) {
		if(!compare(allPoints[i - 1], allPoints[i])) {
			return false;
		}
	}
	return true;
}

bool isBad(const vector < Point > & currentStack, const Point & newPoint) {
	assert(currentStack.size() >= 2);
	const Point & previousPoint = currentStack[currentStack.size() - 2];
	const Point & currentPoint = currentStack[currentStack.size() - 1];
	return ConvexCompare(previousPoint)(newPoint, currentPoint);
}

void buildConvexHull(vector < Point > & allPoints, vector < Point > & currentStack, vector < Point > & newPoints) {
	Point basePoint = *min_element(allPoints.begin(), allPoints.end());
	auto compare = ConvexCompare(basePoint);
	if(!isSorted(allPoints, compare)) {
		sort(allPoints.begin(), allPoints.end(), compare);
	}
	currentStack.push_back(basePoint);
	int isSame = 0;
	for(int i = 0; i < allPoints.size(); i++) {
		const Point & currentPoint = allPoints[i];
		if(currentPoint == basePoint) {
			++isSame;
		} else {
			while(currentStack.size() >= 2 && isBad(currentStack, currentPoint)) {
				const Point & pointToRemove = currentStack.back();
				newPoints.push_back(pointToRemove);
				currentStack.pop_back();
			}
			currentStack.push_back(currentPoint);
		}
	}
	assert(isSame == 1);
}

int main() {
	ios_base::sync_with_stdio(false);
	int pointsCount;
	cin >> pointsCount;
	vector < Point > allPoints(pointsCount);
	for(int i = 0; i < pointsCount; i++) {
		cin >> allPoints[i].x >> allPoints[i].y;
		allPoints[i].id = i;
	}
	sort(allPoints.begin(), allPoints.end());
	vector < int > results(pointsCount);
	for(int it = 1; !allPoints.empty(); it++) {
		vector < Point > convexHull, newPoints;
		buildConvexHull(allPoints, convexHull, newPoints);
		allPoints.swap(newPoints);
		for(const Point & p : convexHull) {
			results[p.id] = it;
		}
	}
	for(int i = 0; i < pointsCount; i++) {
		cout << results[i] << "\n";
	}
	return 0;
}