import java.io.PrintWriter;
import java.util.Scanner;

public class Main {
	
	static double sqr(double a) {
		return a*a;
	}
	
	static boolean doubleEqual(double a, double b) {
		return Math.abs(a-b) < 1e-9;
	}
	
	static boolean doubleLessOrEqual(double a, double b) {
		return a<b || doubleEqual(a, b);
	}
	
	static boolean doubleLess(double a, double b) {
		return a<b && !doubleEqual(a, b);
	}
	
	static boolean doubleGreaterOrEqual(double a, double b) {
		return a>b || doubleEqual(a, b);
	}
	
	static boolean doubleGreater(double a, double b) {
		return a>b && !doubleEqual(a, b);
	}
	
	static double mySqrt(double a) {
		if (doubleLess(a, 0)) {
			throw new RuntimeException("sqrt(-1)");
		}
		if (a<0) return 0;
		return Math.sqrt(a);
	}
	
	static class Point {
		private double x;
		private double y;
		
		public Point(double x, double y) {
			this.x = x;
			this.y = y;
		}
		
		public Point() {
			this(0, 0);
		}
		
		public void scan(Scanner scanner) {
			x = scanner.nextDouble();
			y = scanner.nextDouble();
		}
		
		public void print(PrintWriter printWriter) {
			printWriter.print(x);
			printWriter.print(' ');
			printWriter.println(y);
		}
		
		public Point add(Point p) {
			return new Point(x + p.x, y + p.y);
		}
		
		public Point sub(Point p) {
			return new Point(x - p.x, y - p.y);
		}
		
		public Point minus() {
			return new Point(-x, -y);
		}
		
		public Point mul(double k) {
			return new Point(x*k, y*k);
		}
		
		
		public Point div(double k) {
			return new Point(x/k, y/k);
		}
		
		public double scalarProduct(Point p) {
			return x*p.x + y*p.y;
		}
		
		public double vectorProduct(Point p) {
			return x*p.y - y*p.x;
		}
		
		public double length() {
			return mySqrt(this.scalarProduct(this));
		}
		
		public double distTo(Point p) {
			return this.sub(p).length();
		}
		
		/** distance from this point to line */
		public double distTo(Point A, Point B) {
			double d = A.distTo(B);
			if (doubleEqual(d, 0)) {
				throw new RuntimeException("A = B");
			}
			double s = this.sub(A).vectorProduct(this.sub(B));
			return Math.abs(s) / d;
		}
		
		/** length of vector to k */
		public Point normalize(double k) {
			double len = length();
			if (doubleEqual(len,  0)) {
				if (doubleEqual(k, 0)) {
					return new Point();
				}
				throw new RuntimeException("zero-size vector");
			}
			return this.mul(k/len);
		}
		
		public Point normalize() {
			return normalize(1);
		}
		
		/** projection from this point to line */
		public Point getH(Point A, Point B) {
			Point C = this;
			Point v = B.sub(A);
			Point u = C.sub(A);
			double k = v.scalarProduct(u) / v.length();
			v = v.normalize(k);
			Point H = A.add(v);
			return H;
		}
		
		/** 90 degrees counterclockwise */
		public Point rotate() {
			return new Point(-y, x);
		}
		
		/** counterclockwise */
		public Point rotate(double alpha) {
			return rotate(Math.cos(alpha), Math.sin(alpha));
		}
		
		public Point rotate(double cosa, double sina) {
			Point v = this;
			Point u = v.rotate();
			Point w = v.mul(cosa).add(u.mul(sina));
			return w;
		}
		
		public boolean isZero() {
			return doubleEqual(x, 0) && doubleEqual(y, 0);
		}
		
		public boolean isOnLine(Point A, Point B) {
			return doubleEqual(A.sub(this).vectorProduct(B.sub(this)), 0);
		}
		
		public boolean isInSegment(Point A, Point B) {
			return isOnLine(A, B) && doubleLessOrEqual(A.sub(this).scalarProduct(B.sub(this)), 0);
		}
		
		public boolean isInSegmentStrictly(Point A, Point B) {
			return isOnLine(A, B) && doubleLess(A.sub(this).scalarProduct(B.sub(this)), 0);
		}
		
		/** angle between this and OX */
		public double getAngle() {
			return Math.atan2(y, x);
		}
		
		public double getAngle(Point u) {
			Point v = this;
			return Math.atan2(v.vectorProduct(u), v.scalarProduct(u));
		}
	}
	
	/** of line (A, B) and line(C, D) */
	static Point getIntersection(Point A, Point B, Point C, Point D) {
		Point v = B.sub(A);
		double s1 = C.sub(A).vectorProduct(D.sub(A));
		double s2 = D.sub(B).vectorProduct(C.sub(B));
		double s = s1 + s2;
		if (doubleEqual(s, 0)) {
			if (!A.isOnLine(C, D)) {
				return null; //intersection is empty
			}
			return null; // more then one point in intersection
		}
		v = v.div(s);
		v = v.mul(s1);
		return A.add(v);
	}
	
	static class Point3D {
		private double x;
		private double y;
		private double z;
		public Point3D (double x, double y, double z) {
			this.x = x;
			this.y = y;
			this.z = z;
		}
		
		public Point3D() {
			this(0, 0, 0);
		}
		
		public Point3D add(Point3D p) {
			return new Point3D(x+p.x, y+p.y, z+p.z);
		}
		
		public Point3D sub(Point3D p) {
			return new Point3D(x-p.x, y-p.y, z-p.z);
		}
		
		public Point3D minus() {
			return new Point3D(-x, -y, -z);
		}
		
		public Point3D mul(double k) {
			return new Point3D(x*k, y*k, z*k);
		}
		
		public Point3D div(double k) {
			return new Point3D(x/k, y/k, z/k);
		}
		
		public double scalarProduct(Point3D p) {
			return x*p.x + y*p.y + z*p.z;
		}
		
		public Point3D vectorProduct(Point3D p) {
			return new Point3D (
					y*p.z - z*p.y,
					z*p.x - x*p.z,
					x*p.y - y*p.x);
		}
		
		public double length() {
			return mySqrt(this.scalarProduct(this));
		}
		
		public double distTo(Point3D p) {
			return this.sub(p).length(); 
		}
		
		public Point3D normalize(double k) {
			double len = length();
			if (doubleEqual(len, 0)) {
				if (doubleEqual(k, 0)) {
					return new Point3D();
				}
				throw new RuntimeException("zero-size vector");
			}
			return this.mul(k/len);
		}
		
		public Point3D normalize() {
			return normalize(1);
		}
	}
	
	public static double rasst(Point3D from, Point3D to, Point3D v1, Point3D v2) {
		Point3D vector1 = to.sub(from);
		Point3D normal = v1.vectorProduct(v2).normalize();
		return Math.abs(vector1.scalarProduct(normal));
	}
	
	public static void main(String[] args) {
		Scanner in = new Scanner(System.in);
		int m = in.nextInt();
		int h = in.nextInt();
		int H = in.nextInt();
		int[] x = new int[5];
		int[] y = new int[5];
		for (int i=0; i<5; ++i) {
			x[i] = in.nextInt();
			y[i] = in.nextInt();
		}
		m -= h;
		if (m<0) {
			System.out.println("NO");
			return;
		}
		Point3D x0 = new Point3D(x[0],y[0],h);
		Point3D x1 = new Point3D(x[1],y[1],0);
		Point3D x2 = new Point3D(x[2],y[2],0);
		Point3D x3 = new Point3D(x[3],y[3],0);
		Point3D x4 = new Point3D(x[4],y[4],H);
		
		double minR = h;
		minR = Math.min(minR, rasst(x0, x1, x2.sub(x1), x4.sub(x1)));
		minR = Math.min(minR, rasst(x0, x1, x3.sub(x1), x4.sub(x1)));
		minR = Math.min(minR, rasst(x0, x2, x3.sub(x2), x4.sub(x2)));
		if (minR <= m) {
			System.out.println("YES");
		} else {
			System.out.println("NO");
		}
	}

}
