import java.io.PrintWriter;
import java.util.Arrays;
import java.util.Scanner;

public class Main {
	
	static double sqr(double a) {
		return a*a;
	}
	
	static boolean doubleEqual(double a, double b) {
		return Math.abs(a-b) < 1e-9;
	}
	
	static boolean doubleLessOrEqual(double a, double b) {
		return a<b || doubleEqual(a, b);
	}
	
	static boolean doubleLess(double a, double b) {
		return a<b && !doubleEqual(a, b);
	}
	
	static boolean doubleGreaterOrEqual(double a, double b) {
		return a>b || doubleEqual(a, b);
	}
	
	static boolean doubleGreater(double a, double b) {
		return a>b && !doubleEqual(a, b);
	}
	
	static double mySqrt(double a) {
		if (doubleLess(a, 0)) {
			throw new RuntimeException("sqrt(-1)");
		}
		if (a<0) return 0;
		return Math.sqrt(a);
	}
	
	static class Point {
		public double x;
		public double y;
		
		public Point(double x, double y) {
			this.x = x;
			this.y = y;
		}
		
		public Point() {
			this(0, 0);
		}
		
		public void scan(Scanner scanner) {
			x = scanner.nextDouble();
			y = scanner.nextDouble();
		}
		
		public void print(PrintWriter printWriter) {
			printWriter.print(x);
			printWriter.print(' ');
			printWriter.println(y);
		}
		
		public Point add(Point p) {
			return new Point(x + p.x, y + p.y);
		}
		
		public Point sub(Point p) {
			return new Point(x - p.x, y - p.y);
		}
		
		public Point minus() {
			return new Point(-x, -y);
		}
		
		public Point mul(double k) {
			return new Point(x*k, y*k);
		}
		
		
		public Point div(double k) {
			return new Point(x/k, y/k);
		}
		
		public double scalarProduct(Point p) {
			return x*p.x + y*p.y;
		}
		
		public double vectorProduct(Point p) {
			return x*p.y - y*p.x;
		}
		
		public double length() {
			return mySqrt(this.scalarProduct(this));
		}
		
		public double distTo(Point p) {
			return this.sub(p).length();
		}
		
		/** distance from this point to line */
		public double distTo(Point A, Point B) {
			double d = A.distTo(B);
			if (doubleEqual(d, 0)) {
				throw new RuntimeException("A = B");
			}
			double s = this.sub(A).vectorProduct(this.sub(B));
			return Math.abs(s) / d;
		}
		
		/** length of vector to k */
		public Point normalize(double k) {
			double len = length();
			if (doubleEqual(len,  0)) {
				if (doubleEqual(k, 0)) {
					return new Point();
				}
				throw new RuntimeException("zero-size vector");
			}
			return this.mul(k/len);
		}
		
		public Point normalize() {
			return normalize(1);
		}
		
		/** projection from this point to line */
		public Point getH(Point A, Point B) {
			Point C = this;
			Point v = B.sub(A);
			Point u = C.sub(A);
			double k = v.scalarProduct(u) / v.length();
			v = v.normalize(k);
			Point H = A.add(v);
			return H;
		}
		
		/** 90 degrees counterclockwise */
		public Point rotate() {
			return new Point(-y, x);
		}
		
		/** counterclockwise */
		public Point rotate(double alpha) {
			return rotate(Math.cos(alpha), Math.sin(alpha));
		}
		
		public Point rotate(double cosa, double sina) {
			Point v = this;
			Point u = v.rotate();
			Point w = v.mul(cosa).add(u.mul(sina));
			return w;
		}
		
		public boolean isZero() {
			return doubleEqual(x, 0) && doubleEqual(y, 0);
		}
		
		public boolean isOnLine(Point A, Point B) {
			return doubleEqual(A.sub(this).vectorProduct(B.sub(this)), 0);
		}
		
		public boolean isInSegment(Point A, Point B) {
			return isOnLine(A, B) && doubleLessOrEqual(A.sub(this).scalarProduct(B.sub(this)), 0);
		}
		
		public boolean isInSegmentStrictly(Point A, Point B) {
			return isOnLine(A, B) && doubleLess(A.sub(this).scalarProduct(B.sub(this)), 0);
		}
		
		/** angle between this and OX */
		public double getAngle() {
			return Math.atan2(y, x);
		}
		
		public double getAngle(Point u) {
			Point v = this;
			return Math.atan2(v.vectorProduct(u), v.scalarProduct(u));
		}
	}
	
	/** of line (A, B) and line(C, D) */
	static Point getIntersection(Point A, Point B, Point C, Point D) {
		Point v = B.sub(A);
		double s1 = C.sub(A).vectorProduct(D.sub(A));
		double s2 = D.sub(B).vectorProduct(C.sub(B));
		double s = s1 + s2;
		if (doubleEqual(s, 0)) {
			if (!A.isOnLine(C, D)) {
				return null; //intersection is empty
			}
			return null; // more then one point in intersection
		}
		v = v.div(s);
		v = v.mul(s1);
		return A.add(v);
	}
	
	static Point getSegmentsIntersection(Point A, Point B, Point C, Point D) {
		Point O = getIntersection(A, B, C, D);
		if (O == null) return null;
		if (O.isInSegment(A, B) && O.isInSegment(C, D)) return O;
		return null;
	}
	
	static double getTriangleArea(Point A, Point B, Point C) {
		double Al = A.sub(B).length();
		double Bl = B.sub(C).length();
		double Cl = C.sub(A).length();
		//System.out.println(Al+" "+Bl+" "+Cl);
		double P = (Al+Bl+Cl)/2;
		return mySqrt(P*(P-Al)*(P-Bl)*(P-Cl));
	}
	
	static boolean isPointInTriangle(Point P, Point A, Point B, Point C) {
		return doubleEqual(
				getTriangleArea(A, B, C),
				getTriangleArea(A, B, P) + getTriangleArea(A, P, C) + getTriangleArea(P, B, C));
	}
	
	static class Point3D {
		private double x;
		private double y;
		private double z;
		public Point3D (double x, double y, double z) {
			this.x = x;
			this.y = y;
			this.z = z;
		}
		
		public Point3D() {
			this(0, 0, 0);
		}
		
		public Point3D add(Point3D p) {
			return new Point3D(x+p.x, y+p.y, z+p.z);
		}
		
		public Point3D sub(Point3D p) {
			return new Point3D(x-p.x, y-p.y, z-p.z);
		}
		
		public Point3D minus() {
			return new Point3D(-x, -y, -z);
		}
		
		public Point3D mul(double k) {
			return new Point3D(x*k, y*k, z*k);
		}
		
		public Point3D div(double k) {
			return new Point3D(x/k, y/k, z/k);
		}
		
		public double scalarProduct(Point3D p) {
			return x*p.x + y*p.y + z*p.z;
		}
		
		public Point3D vectorProduct(Point3D p) {
			return new Point3D (
					y*p.z - z*p.y,
					z*p.x - x*p.z,
					x*p.y - y*p.x);
		}
		
		public double length() {
			return mySqrt(this.scalarProduct(this));
		}
		
		public double distTo(Point3D p) {
			return this.sub(p).length(); 
		}
		
		public Point3D normalize(double k) {
			double len = length();
			if (doubleEqual(len, 0)) {
				if (doubleEqual(k, 0)) {
					return new Point3D();
				}
				throw new RuntimeException("zero-size vector");
			}
			return this.mul(k/len);
		}
		
		public Point3D normalize() {
			return normalize(1);
		}
	}
	
	/*public static void main(String[] args) {
		Scanner in = new Scanner(System.in);
		Point A = new Point(0, 0);
		Point B = new Point(10, 0);
		Point C = new Point(10, 10);
		Point F = new Point();
		F.scan(in);
		
		double S = 25.0;
		double inc = 50.0;
		double minX = 0.0;
		double maxX = 10.0;
		double minY = 0.0;
		double maxY = 10.0;
		boolean xxx = false;
		
		while (!doubleLess(inc, 1e-4)) {
			inc /= 2.0;
			if (xxx) {
				double x = ( minX + maxX ) / 2;
				if (x>F.x) {
					maxX = x;
					S -= inc;
				} else {
					minX = x;
					//S += inc;
				}
			} else {
				double y = ( minY + maxY ) / 2;
				if (y>F.y) {
					maxY = y;
					S -= inc;
				} else {
					minY = y;
					//S += inc;
				}
			}
			xxx = !xxx;
		}
		System.out.println(S);
	}*/
	
	public static void main(String[] args) {
		Scanner in = new Scanner(System.in);
		Point A0 = new Point(0, 0);
		Point A = new Point(0, 0);
		Point B = new Point(10, 0);
		Point C = new Point(10, 10);
		Point F = new Point();
		F.scan(in);
		if (doubleEqual(F.x, F.y)) {
			System.out.println("0");
			return;
		}
				
		double S = 50.0;
		double dec = 50.0;
		
		while (!doubleEqual(dec, 0)) {
			dec /= 2;
			
			Point H = B.getH(A, C);
			
			Point intersection = getSegmentsIntersection(B, H, A0, F);
			//System.out.println("B: "+B.x+";"+B.y+" H:"+H.x+";"+H.y);
			//if (intersection != null)
			//	System.out.println("intersection: "+intersection.x+";"+intersection.y);
			//else System.out.println("ne peresekaet");
			if (intersection == null) {
				S -= dec;
				//System.out.println("dec: "+dec);
			} else {
				//if (doubleLess(intersection.distTo(B), 1e-4)) {
				//	S -= dec;
				//} else
				if (doubleEqual(intersection.distTo(F), 0)) {
					S -= dec;
					break;
				}
				//if (doubleLess(in))
			}
			
			if (isPointInTriangle(F, A, B, H)) {
				C = B;
				B = H;
			} else {
				A = B;
				B = H;
			}
		}
		//Double.to
		System.out.println(S);
		
	}
	
	/*static int partition(Point arr[], int indexarr[], int left, int right) {
	    int i = left, j = right;
	    Point tmp;
	    int tmpindex;
	    double pivot = arr[(left + right) / 2].x;
	    
	    while (i <= j) {
	        while (arr[i].x < pivot)
	            i++;
	        while (arr[j].x > pivot)
	            j--;
	        if (i <= j) {
	            tmp = arr[i];
	            arr[i] = arr[j];
	            arr[j] = tmp;
	            tmpindex = indexarr[i];
	            indexarr[i] = indexarr[j];
	            indexarr[j] = tmpindex;
	            i++;
	            j--;
	        }
	    };
	     
	    return i;
	}
	
	static void quickSort (Point arr[], int indexarr[], int left, int right) {
	    int index = partition(arr, indexarr, left, right);
	    if (left < index - 1)
	        quickSort (arr, indexarr, left, index - 1);
	    if (index < right)
	        quickSort (arr, indexarr, index, right);
	}
	
	public static void main(String[] args) {
		Scanner in = new Scanner(System.in);
		int n = in.nextInt();
		Point[] points = new Point[n];
		
		Point[] toBuild = new Point[n];
		int[] toBuildIndexes = new int[n];
		int toBuildCount;
		
		for (int i=0;i<n;++i) {
			points[i] = new Point();
			points[i].scan(in);
		}
		
		int[] old_index = new int[n];
		for (int i=0;i<n;++i) old_index[i] = i;
		
		quickSort(points, old_index, 0, n-1);
		
		boolean[] used = new boolean[n];
		int[] counts = new int[n];
		
		boolean done = false;
		while (!done) {
			toBuildCount = 0;
			for (int i=0;i<n;++i) {
				if (!used[i]) {
					++counts[old_index[i]];
					toBuild[toBuildCount] = points[i];
					toBuildIndexes[toBuildCount++] = i;
				}
			}
		
			/////
			
			
			done = true;
			for (int i=0;i<n;++i) if (!used[i]) done = false;
		}
		
		for (int i=0;i<n;++i) {
			System.out.println("point: "+points[i].x+";"+points[i].y+" index:"+old_index[i]);
		}
		
	}*/
	
	/*public static double rasst(Point3D from, Point3D to, Point3D v1, Point3D v2) {
		Point3D vector1 = to.sub(from);
		Point3D normal = v1.vectorProduct(v2).normalize();
		return Math.abs(vector1.scalarProduct(normal));
	}
	
	public static void main(String[] args) {
		Scanner in = new Scanner(System.in);
		int m = in.nextInt();
		int h = in.nextInt();
		int H = in.nextInt();
		int[] x = new int[5];
		int[] y = new int[5];
		for (int i=0; i<5; ++i) {
			x[i] = in.nextInt();
			y[i] = in.nextInt();
		}
		m -= h;
		if (m<0) {
			System.out.println("NO");
			return;
		}
		Point3D x0 = new Point3D(x[0],y[0],h);
		Point3D x1 = new Point3D(x[1],y[1],0);
		Point3D x2 = new Point3D(x[2],y[2],0);
		Point3D x3 = new Point3D(x[3],y[3],0);
		Point3D x4 = new Point3D(x[4],y[4],H);
		
		double minR = h;
		minR = Math.min(minR, rasst(x0, x1, x2.sub(x1), x4.sub(x1)));
		minR = Math.min(minR, rasst(x0, x1, x3.sub(x1), x4.sub(x1)));
		minR = Math.min(minR, rasst(x0, x2, x3.sub(x2), x4.sub(x2)));
		if (minR <= m) {
			System.out.println("YES");
		} else {
			System.out.println("NO");
		}
	}*/

}
