#include <iostream>
#include <cmath>
#include <vector>
#include <stack>
#include <algorithm>

using namespace std;

const double eps = 1e-9;

struct Point;

double getAngle(Point& p);

struct Point
{
	int x, y;
	bool used;
	int hull;
	int index;

	Point():x(0),y(0),used(false),hull(0){}
	Point(int x, int y):x(x),y(y),used(false),hull(0),index(0){}

	Point operator -(Point& a)
	{
		return Point(x - a.x, y - a.y);
	}

	int operator *(Point& a)
	{
		return x*a.y - y*a.x;
	}

	bool operator ==(Point& a)
	{
		return a.x == x && a.y == y;
	}
};

Point leftmost;

template<class T>
ostream& operator << (ostream& s, vector<T>& vec)
{
	for(size_t i = 0; i < vec.size(); i++)
		s << vec[i] << ' ';
	return s;
}

ostream& operator << (ostream& s, Point&p)
{
	s << p.x << ';' << p.y << ' ';
	return s;
}

inline double getAngle(Point& p)
{
	//cerr << "Angle between " << p << " and ox is " << atan2((double)p.y, (double)p.x) << endl;
	return atan2((double)p.y, (double)p.x);
}

bool cmp(Point& a, Point& b)
{
	//cerr << "Compare " << a << " and " << b << endl;
	return (getAngle(a - leftmost) - getAngle(b - leftmost)) < -eps;
}

bool index_cmp(Point& a, Point& b)
{
	return a.index < b.index;
}

int main()
{
	int N, leftmost_index = 0;
	int points_in_hull = 0, hull_cnt = 0;
	cin >> N;
	vector<Point> points(N+1);
	for(int i = 0; i < N; i++)
	{
		cin >> points[i].x >> points[i].y;
		points[i].index = i+1;
	}
	for(int points_left = N; points_left; points_left -= points_in_hull)
	{
		hull_cnt++;
		points_in_hull = 0;
		leftmost_index = 0;
		leftmost = Point(1000000, 1000000);
		for(int i = 0; i < N; i++)
		{
			if(points[leftmost_index].used)
				leftmost_index = i;
			if(!points[i].used)
			{
				if(points[i].x < leftmost.x)
				{
					leftmost = points[i];
					leftmost_index = i;
				}
			}
		}
		leftmost.index = 0;
		leftmost.used = true;
		//cerr << leftmost << endl;
		points[leftmost_index].used = true;
		points[N] = leftmost;

		//cerr << points << endl;
		sort(points.begin(), --points.end(), cmp);
		//cerr << points << endl;

		stack<int> hull;
		for(int i = 0; i < N; i++)
		{
			if(points[i] == leftmost)
			{
				leftmost_index = i;
				break;
			}
		}
		hull.push(leftmost_index);
		int last_point = N;
		for(int i = 0; i <= N; i++)
		{
			if(!points[i].used)
			{
				last_point = i;
				points[i].used = true;
				break;
			}
		}
		for(int i = last_point + 1; i <= N; i++)
		{
			//cerr << "Top of stack is " << hull.top() << endl;
			if(!points[i].used)
			{
				do
				{
					Point prev = points[last_point] - points[hull.top()];
					Point cur = points[i] - points[last_point];
					int product = prev*cur;
					if(product > 0)
					{
						hull.push(last_point);
						last_point = i;
						points[i].used = true;
					}
					else
					{
						points[last_point].used = false;
						last_point = hull.top();
						hull.pop();
					}
				}while(!points[i].used);
			}
			else if(i == N)
			{
				break;
			}
		}
		if(last_point != N)
			hull.push(last_point);
		while(!hull.empty())
		{
			//cerr << points[hull.top()].index << ' ';
			points[hull.top()].hull = hull_cnt;
			points_in_hull++;
			hull.pop();
		}
	}
	sort(points.begin(), points.end(), index_cmp);
	for(size_t i = 0; i <  points.size(); i++)
	{
		if(points[i].index)
			cout << points[i].hull << endl;
	}
	//cin >> N;
}