#include <iostream>
#include <algorithm>
#include <cstring>
#include <cstdio>
#include <cstdlib>
#include <cmath>

using namespace std;

const int MAX_N = 105;
double eps = 1e-10;

struct Point3D {
    double x, y, z;

    Point3D(double X = 0, double Y = 0, double Z = 0): x(X), y(Y), z(Z) {
    }
};

struct Point2D {
    double x, y;

    Point2D(double X = 0, double Y = 0): x(X), y(Y) {
    }
};

int n, z1, z2;
Point3D p[MAX_N];

bool equal(double a, double b) {
    return fabs(a - b) < eps;
}

bool greatr(double a, double b) {
    if (a - b > eps) {
        return true;
    }

    return false;
}

bool greaterEqual(double a, double b) {
    if (greatr(a, b) || equal(a, b)) {
        return true;
    }

    return false;
}

Point2D intersect(Point3D p1, Point3D p2, int z) {
    if (greatr(p1.z, p2.z)) {
        swap(p1, p2);
    }

    return Point2D(p1.x + (p2.x - p1.x) * (z - p1.z) / (p2.z - p1.z),
            p1.y + (p2.y - p1.y) * (z - p1.z) / (p2.z - p1.z));
}

double ccw(Point2D a, Point2D b, Point2D c) {
    double x1 = a.x - b.x, x2 = c.x - b.x;
    double y1 = a.y - b.y, y2 = c.y - b.y;

    return x1 * y2 - x2 * y1;
}

double area(Point2D p[], int n) {
    int mn = 0;
    pair< double, int > s[MAX_N];

    for (int i = 0; i < n; i++) {
        if (p[i].y < p[mn].y) {
            mn = i;
        } else if (p[i].y == p[mn].y && p[i].x < p[mn].x) {
            mn = i;
        }

        s[i] = make_pair(atan2(p[i].y, p[i].x), i);
    }

    sort(s, s + n);

    int sz = 0, hull[MAX_N];

    for (int i = 0; i < n; i++) {
        int u = s[i].second;

        while (sz > 1 && ccw(p[hull[sz - 2]], p[hull[sz - 1]], p[u]) > 0) {
            sz--;
        }

        hull[sz++] = u;
    }
    
    while (sz >= 3 && ccw(p[hull[sz - 2]], p[hull[sz - 1]], p[hull[0]]) > 0) {
        sz--;
    }

    double ans = 0.0;

    for (int j = 1; j < sz - 1; j++) {
        ans += fabs(ccw(p[hull[0]], p[hull[j]], p[hull[j + 1]])) / 2.0;
    }

    return ans;
}

int main() {
    scanf("%d %d %d", &n, &z1, &z2);

    for (int i = 0; i < n; i++) {
        scanf("%lf %lf %lf", &p[i].x, &p[i].y, &p[i].z);
    }

    for (int z = z1; z <= z2; z++) {
        int sz = 0;
        Point2D cur_p[MAX_N];

        for (int i = 0; i < n; i++) {
            for (int j = i + 1; j < n; j++) {
                if ((greaterEqual(z, p[i].z) && greaterEqual(p[j].z, z)) || (greaterEqual(p[i].z, z) && greaterEqual(z, p[j].z))) {
                    if (!equal(p[i].z, z) || !equal(p[j].z, z)) {
                        cur_p[sz++] = intersect(p[i], p[j], z);
                    }
                }

            }

            if (equal(p[i].z, z)) {
                cur_p[sz++] = Point2D(p[i].x, p[i].y);
            }
        }

        printf("%.9lf\n", area(cur_p, sz));
    }

    return 0;
}
