#include <iostream>
#include <iomanip>
#include <vector>
#include <bitset>
#include <algorithm>
#include <queue>
#include <cstdio>
#include <set>
#include <map>
#include <unordered_set>
#include <unordered_map>

using namespace std;
typedef int huint;
typedef long long ll;
#define mp make_pair
#define pb push_back
#define all(x) x.begin(),x.end()

struct v2{
	double x, y, z;
	v2() {}
	v2(const double x, const double y, const double z): x(x), y(y), z(z) {}
	v2 operator +(const v2& r) const{
		return v2(x + r.x, y + r.y, z + r.z); }
	v2 operator -(const v2& r) const{
		return v2(x - r.x, y - r.y, z - r.z); }
	v2 operator *(const double r) const{
		return v2(x * r, y * r, z * r) ; }
	double sqlen() const{
		return x * x + y * y + z * z; }
	bool operator <(const v2& r) {
		return x < r.x || x == r.x && y < r.y; }
};
double dot(const v2& l, const v2& r) {
	return l.x * r.x + l.y * r.y;
}
double cross(const v2& l, const v2& r) {
	return l.x * r.y - l.y * r.x;
}
const double EPS = 1e-10;
inline int sign(double x) {
	if (x < -EPS) return -1;
	if (x > EPS) return +1;
	return  0;
}

struct CMP{
	v2 O;
	CMP(const v2& O): O(O) {}
	bool operator () (const v2& l, const v2& r){
		int s = sign(cross(l - O, r - O));
		return s > 0 || s == 0 && (l - O).sqlen() < (r - O).sqlen();
	}
};

const int N = 202;
vector<v2> hull;

inline double f(vector<v2>& pts){
	hull.resize(0);
	v2 base = pts[0];
	for (int i = 1; i < pts.size(); ++i)
		if (pts[i] < base)
			base = pts[i];
	sort(pts.begin(), pts.end(), CMP(base));
	for (int i = 0; i < pts.size(); ++i){
		v2 x = pts[i];
		while (hull.size() > 1 && cross(hull.back() - hull[hull.size() - 2], x - hull[hull.size() - 2]) < 0)
			hull.pop_back();
		hull.push_back(x);
	}
	double ans = 0;
	for (int i = 0; i < hull.size(); ++i) {
		ans += cross(hull[i], hull[(i + 1) % hull.size()]);
	}
	return ans / 2;
}



int main(){
	ios_base::sync_with_stdio(false);
	int n;
	cin >> n;
	int zmin, zmax;
	cin >> zmin >> zmax;
	vector<v2> aa;
	for (int i = 0; i < n; ++i){
		int x, y, z;
		cin >> x >> y >> z;
		aa.push_back(v2(x, y, z));
	}
	
	vector<v2> cur;
	for (int i = zmin; i <= zmax; ++i){
		cur.resize(0);
		for (int j = 0; j < aa.size(); ++j){
			if (aa[j].z == i) {
				cur.push_back(aa[j]);
				continue;
			}
			if (aa[j].z < i){
				for (int k = 0; k < aa.size(); ++k) if (aa[k].z > i) {
					v2 l = aa[j];
					v2 r = aa[k];
					v2 v = l + (r - l) * ((i - l.z) / (r.z - l.z));
					cur.push_back(v);
				}
			}
		}

		
		cout << fixed << setprecision(10) << f(cur) << endl;
	}
	
	return 0;
}