#include <iostream>
#include <algorithm>
#include <string>
#include <vector>
#include <set>
#include <map>
#include <queue>
#include <bitset>
#include <sstream>
#include <cstdio>
#include <cstring>
#include <cmath>
#include <climits>
#include <cctype>
#include <cstdlib>
using namespace std;

#define FOR(i,a,b) for(int i=(a);i<(b);i++)
#define ROF(i,a,b) for(int i=(b)-1;i>=(a);i--)

typedef long long LL;
typedef LL ll;
typedef pair<int, int> pii;

const int kInf = 1000 * 1000 * 1000;
const int INF = kInf;

struct Vector {
  double x, y;

  Vector(double x = 0.0, double y = 0.0) : x(x), y(y) {}
};

Vector operator+(const Vector& u, const Vector& v) {
  return Vector(u.x + v.x, u.y + v.y);
}

Vector operator-(const Vector& u, const Vector& v) {
  return Vector(u.x - v.x, u.y - v.y);
}

double dot(const Vector& u, const Vector& v) {
  return u.x * v.x + u.y * v.y;
}

double cross(const Vector& u, const Vector& v) {
  return u.x * v.y - u.y * v.x;
}

Vector operator*(double k, const Vector& u) {
  return Vector(k * u.x, k * u.y);
}
Vector operator*(const Vector& u, double k) {
  return Vector(k * u.x, k * u.y);
}

typedef Vector Point;

const ll LINF = 1e18;

bool online(Vector const& a, Vector const& b, Vector const& p) {
  if (fabs(cross(p - a, b - a)) > 1e-9) return false;
  if (dot(p - a, b - a) < -1e-9) return false;
  if (dot(p - b, a - b) < -1e-9) return false;
  return true;
}

int main() {
  Vector a(0, 0), b(10, 10), c(10, 0);
  Vector p;
  cin >> p.x >> p.y;
  double answer = 0;
  double area = 50;
  Vector q(-p.y, p.x);
  for (int i = 0; i < 1000; i++) {
    Vector d = (a + b) * 0.5;
    Vector n(d.y - c.y, c.x - d.x);
    double z = dot(n, c);
    double dist = dot(n, p) - z;
    area /= 2;
    if (fabs(dist) < 1e-6) {
      answer += area;
      break;
    }
    if ((dot(n, a) - z) * dist > 0) {
      if ((-z) * (dot(n, a) - z) < 1e-9 && dot(q, c) * dot(q, d) < -1e-9) answer += area;
      b = c;
      c = d;
    } else {
      if ((-z) * (dot(n, a) - z) > -1e-9 && dot(q, c) * dot(q, d) < -1e-9) answer += area;
      a = c;
      c = d;
    }
  }
  cout.precision(6);
  cout << fixed << answer;
  return 0;
}
