#include <iostream>
#include <algorithm>
#include <string>
#include <vector>
#include <set>
#include <map>
#include <queue>
#include <bitset>
#include <sstream>
#include <cstdio>
#include <cstring>
#include <cmath>
#include <climits>
#include <cctype>
#include <cstdlib>
using namespace std;

#define FOR(i,a,b) for(int i=(a);i<(b);i++)
#define ROF(i,a,b) for(int i=(b)-1;i>=(a);i--)

typedef long long LL;
typedef LL ll;
typedef pair<int, int> pii;
const int INF = 1000000000;
const LL LINF = 1000000000000000000LL;
const double PI = 3.1415926535897932384626433832795;

struct Vector {
  double x, y;

  Vector(double x = 0.0, double y = 0.0) : x(x), y(y) {}
};

Vector operator+(const Vector& u, const Vector& v) {
  return Vector(u.x + v.x, u.y + v.y);
}

Vector operator-(const Vector& u, const Vector& v) {
  return Vector(u.x - v.x, u.y - v.y);
}

double dot(const Vector& u, const Vector& v) {
  return u.x * v.x + u.y * v.y;
}

double cross(const Vector& u, const Vector& v) {
  return u.x * v.y - u.y * v.x;
}

Vector operator*(double k, const Vector& u) {
  return Vector(k * u.x, k * u.y);
}
Vector operator*(const Vector& u, double k) {
  return Vector(k * u.x, k * u.y);
}
typedef Vector Point;

struct Line {
  Vector n;
  double d;
  double angle;
  Line() {}
  Line(Vector const& v, double gd) : n(v), d(gd) {
    d = -d;
    angle = atan2(n.y, n.x);
    if (angle < -PI / 2 - 1e-8) angle += 2 * PI;
  }
};
Point intersect(Line const& a, Line const& b) {
  double den = cross(a.n, b.n);
  if (fabs(den) < 1e-8) {
    return a.n * (-a.d / dot(a.n, a.n));
  }
  return Vector(
    (-a.d * b.n.y + b.d * a.n.y) / den,
    (-a.n.x * b.d + b.n.x * a.d) / den
  );
}

vector<Line> lines;

bool operator < (Point const& a, Point const& b) {
  return a.x < b.x - 1e-8 || (fabs(a.x - b.x) <= 1e-8 && a.y < b.y - 1e-8);
}
bool operator == (Point const& a, Point const& b) {
  return fabs(a.x - b.x) <= 1e-8 && fabs(a.y - b.y) <= 1e-8;
}

bool comparator(Line const& a, Line const& b) {
  if (fabs(a.angle - b.angle) < 1e-8) return a.d > b.d;
  return a.angle < b.angle;
}
bool lequal(Line const& a, Line const& b) {
  return fabs(a.angle - b.angle) < 1e-8;
}
double GetArea() {
  sort(lines.begin(), lines.end(), comparator);
  lines.resize(unique(lines.begin(), lines.end(), lequal) - lines.begin());

  vector<Point> poly;
  vector<Line> linelist;
  for (int s = 0; s < 2; s++) {
    for (int i = 0; i < lines.size(); i++) {
      while (poly.size() && dot(poly.back(), lines[i].n) + lines[i].d > -1e-8) {
        poly.pop_back();
        linelist.pop_back();
      }
      if (linelist.size()) {
        poly.push_back(intersect(lines[i], linelist.back()));
      }
      linelist.push_back(lines[i]);
    }
  }
  map<Point, int> pset;
  int first = -1;
  int last = -1;
  for (int i = 0; i < poly.size(); i++) {
    if (pset.find(poly[i]) != pset.end()) {
      first = pset[poly[i]];
      last = i;
    }
    pset[poly[i]] = i;
  }
  if (last - first < 3) return 0;
  FOR(i, first, last) {
    if (fabs(poly[i].x) > 1e+9 || fabs(poly[i].y) > 1e+9) {
      return -1;
    }
  }
  double answer = 0;
  for (int i = first + 2; i < last; i++) {
    answer += fabs(cross(poly[i] - poly[first], poly[i - 1] - poly[first])) * 0.5;
  }
  return answer;
}

int main() {
  int n;
  scanf("%d", &n);
  lines.push_back(Line(Vector(1, 0), 1e+10));
  lines.push_back(Line(Vector(-1, 0), 1e+10));
  lines.push_back(Line(Vector(0, 1), 1e+10));
  lines.push_back(Line(Vector(0, -1), 1e+10));
  FOR(i, 0, n) {
//    int x1, x2, y1, y2;
//    scanf("%d%d%d%d", &x1, &y1, &x2, &y2);
    int a, b, c;
    scanf("%d%d%d", &a, &b, &c);
    lines.push_back(Line(Vector(a, b), c));
  }
  double area = GetArea();
  if (area < 0) printf("-1");
  else printf("%.9lf", area);
  return 0;
}
