#include <iostream>
#include <algorithm>
#include <string>
#include <vector>
#include <set>
#include <map>
#include <queue>
#include <bitset>
#include <sstream>
#include <cstdio>
#include <cstring>
#include <cmath>
#include <climits>
#include <cctype>
#include <cstdlib>
using namespace std;

#define FOR(i,a,b) for(int i=(a);i<(b);i++)
#define ROF(i,a,b) for(int i=(b)-1;i>=(a);i--)

typedef long long LL;
typedef LL ll;
typedef pair<int, int> pii;

const int kInf = 1000 * 1000 * 1000;
const int INF = kInf;

struct Vector {
  int x, y;//, ind;

  Vector(int x = 0, int y = 0) : x(x), y(y) {}
};

Vector operator+(const Vector& u, const Vector& v) {
  return Vector(u.x + v.x, u.y + v.y);
}

Vector operator-(const Vector& u, const Vector& v) {
  return Vector(u.x - v.x, u.y - v.y);
}

int dot(const Vector& u, const Vector& v) {
  return u.x * v.x + u.y * v.y;
}

int cross(const Vector& u, const Vector& v) {
  return u.x * v.y - u.y * v.x;
}

Vector operator*(double k, const Vector& u) {
  return Vector(k * u.x, k * u.y);
}
Vector operator*(const Vector& u, double k) {
  return Vector(k * u.x, k * u.y);
}

bool operator==(const Vector& u, const Vector& v) {
  return u.x == v.x && u.y == v.y;
}

typedef Vector Point;

const ll LINF = 1e18;
int timer = 0;
vector<int> ans;
map <pair <int, int>, vector <int> > points;

void ConvexHull(const vector<Vector>& arr, vector<char>& used) {
   ++timer;
  if (arr.size() <= 3) {
    for (int i = 0; i < arr.size(); ++i) {
      auto curr = points.find(pii(arr[i].x, arr[i].y));
      for (auto it = curr->second.begin(); it != curr->second.end(); ++it) {
        ans[*it] = timer;
      }
      
      //ns[arr[i].ind] = timer;
      used[i] = 1;
    }
     return;
  }
  Vector p = arr[0];
  int ind = 0;
  for (int i = 1; i < arr.size(); ++i) {
    if (arr[i].x < p.x || arr[i].x == p.x && arr[i].y < p.y) {
      p = arr[i];
      ind = i;
    }
  }
  int n = arr.size();
  used.resize(n);
  used[ind] = 1;

  auto curr = points.find(pii(p.x, p.y));
  for (auto it = curr->second.begin(); it != curr->second.end(); ++it) {
    ans[*it] = timer;
  }

  //ans[p.ind] = timer;
  while (true) {
    Vector x = p;
    int ind = -1;
    for (int i = 0; i < n; ++i) {
      Vector y = arr[i];
      //if (used[i]) {
      if (y == p) {
        continue;
      }
      if (x == p || cross(y - p, x - p) > 0 || cross(y - p, x - p) == 0 && dot(y - p, y - p) < dot(x - p, x - p) ||
          cross(y - p, x - p) == 0 && dot(y - p, y - p) == dot(x - p, x - p) && !used[i]) {
        x = y;
        ind = i;
      }
    }
    if (used[ind]) {
      break;
    }
    used[ind] = true;
    p = arr[ind];

    auto curr = points.find(pii(p.x, p.y));
    for (auto it = curr->second.begin(); it != curr->second.end(); ++it) {
      ans[*it] = timer;
    }

    //ans[p.ind] = timer;
  }
}

int main() {
  std::ios_base::sync_with_stdio(false);
  int n;
  cin >> n;
  vector<Vector> arr;//(n);



  for (int i = 0; i < n; ++i) {
    int x, y;
    cin >> x >> y;//arr[i].x >> arr[i].y;
    points[pii(x, y)].push_back(i);

    //arr[i].ind = i;
  }

  for (auto it = points.begin(); it != points.end(); ++it)
    arr.push_back(Vector(it->first.first, it->first.second));

  ans.resize(n);
  while (true) {
    vector<char> used(arr.size());
    ConvexHull(arr, used);
    vector<Vector> buff;
    for (int i = 0; i < arr.size(); ++i) {
      if (used[i]) {
        continue;
      }
      buff.push_back(arr[i]);
    }
    if (buff.empty()) {
      break;
    }
    arr = buff;
  }
  for (int i = 0; i < n; ++i)
    cout << ans[i] << '\n';
  return 0;
}