#include <iostream>
#include <cstdio>
#include <vector>
#include <map>
#include <algorithm>
#include <set>
#include <cstdlib>
#include <cstring>
#include <cmath>

using namespace std;

const long double EPS = 1e-9;

struct Point {
    long double x, y, z;

    Point() {}

    Point(long double x, long double y, long double z): x(x), y(y), z(z) {}

    Point operator+(const Point &p) const {
        return Point(x + p.x, y + p.y, z + p.z);
    }

    Point operator-(const Point &p) const {
        return Point(x - p.x, y - p.y, z - p.z);
    }

    Point operator/(long double k) const {
        return Point(x / k, y / k, z / k);
    }
};

long double sp(const Point &a, const Point &b) {
    return a.x * b.x + a.y * b.y + a.z * b.z;
}

Point cp(const Point &a, const Point &b) {
    return Point(a.y * b.z - a.z * b.y, a.z * b.x - a.x * b.z, a.x * b.y - a.y * b.x);
}

long double len(const Point &p) {
    return sqrt(sp(p, p));
}

bool inSemispace(const Point &p, const Point &a, const Point &b, const Point &c) {
    return sp(cp(p - a, b - a), c - a) > EPS;
}

long double getS(const Point &a, const Point &b, const Point &c) {
    return len(cp(b - a, c - a)) / 2;
}

long double getH(const Point &a, const Point &b, const Point &c, const Point &d) {
    return fabs(sp(cp(b - a, c - a), d - a)) / getS(b, c, d) / 2;
}

int main(){
    ios_base::sync_with_stdio(false);
    int m, h, H;
    cin >> m >> h >> H;
    Point p, a, b, c, d;
    cin >> p.x >> p.y >> a.x >> a.y >> b.x >> b.y >> c.x >> c.y >> d.x >> d.y;
    p.z = h;
    a.z = 0;
    b.z = 0;
    c.z = 0;
    d.z = H;
    m -= h;
    long double dist = min(min(getH(p, a, b, c), getH(p, b, c, d)), min(getH(p, c, d, a), getH(p, d, a, b)));
    if(dist > m + EPS)
        cout << "NO\n";
    else
        cout << "YES\n";
    return 0;
}
