#include <cstdio>
#include <iostream>
#include <vector>
#include <algorithm>
#include <cstring>
#include <string>
#include <cmath>
#include <map>
#include <set>
#include <climits>
#include <cassert>
#include <cctype>
#include <queue>
using namespace std;

typedef long long ll;
typedef double dbl;
typedef long double ld;

#define mp make_pair
#define pb push_back
#define sz(x) (int)x.size()
#define all(x) x.begin(),x.end()
#define X first
#define Y second

const ll maxn = 5000*100 + 10;
const dbl eps = 1e-9;

bool is_equal(dbl a, dbl b) {
	return fabs(a - b) < eps;
}

bool is_less(dbl a, dbl b) {
	return !is_equal(a, b) && a < b;
}

bool is_bigger(dbl a, dbl b) {
	return !is_equal(a, b) && a > b;
}

bool is_equal_less(dbl a, dbl b) {
	return is_equal(a, b) || is_less(a, b);
}

bool is_equal_bigger(dbl a, dbl b) {
	return is_equal(a, b) || is_bigger(a, b);
}

struct Point {
	dbl x, y;
	int pos;
	Point() {};
	Point(dbl x, dbl y) : x(x), y(y) {};

	void scan() {
		scanf("%lf %lf", &x, &y);
	}
	
	void print() {
		printf("%.10lf %.10lf\n", x, y);
	}

	Point operator+(const Point &p) const {
		return Point(x + p.x, y + p.y);
	}

	Point operator-(const Point &p) const {
		return Point(x - p.x, y - p.y);
	}

	bool operator<(const Point &p) const {
		return x < p.x || x == p.x && y < p.y;
	}
};

struct Plane {
	double a, b, c, d;
};

double det (double a, double b, double c, double d) {
	return a*d - b*c;
}

Plane make_plane(Point a, Point b, Point c) {
	Plane p;
	/*(p.a = det(b.y - a.y, b.z - a.z, c.y - a.y, c.z - a.z);
	p.b = -det(b.x - a.x, b.z - a.z, c.x - a.x, c.z - a.z);
	p.c = det(b.x - a.x, b.y - a.y, c.x - a.x, c.y - a.y);
	p.d = -(p.a*a.x + p.b*a.y + p.c*a.z);*/
	return p;
}

double dist(Plane pl, Point p) {
	//return fabs(pl.a*p.x + pl.b*p.y + pl.c*p.z + pl.d)/sqrt(pl.a*pl.a + pl.b*pl.b + pl.c*pl.c);
	return 0.0;
}

bool cmp (Point a, Point b) {
	return a.x < b.x || a.x == b.x && a.y < b.y;
}

bool cw (Point a, Point b, Point c) {
	return a.x*(b.y - c.y) + b.x*(c.y - a.y) + c.x*(a.y - b.y) <= 0;
}

bool ccw (Point a, Point b, Point c) {
	return a.x*(b.y - c.y) + b.x*(c.y - a.y) + c.x*(a.y - b.y) >= 0;
}

void convex_hull(vector <Point> & a) {
	if (a.size() == 1) return;
	sort(all(a), cmp);
	Point p1 = a[0], p2 = a.back();
	vector <Point> up, down;
	up.pb(p1);
	down.pb(p1);
	for (int i = 1; i < sz(a); i++) {
		if (i == sz(a) - 1 || cw(p1, a[i], p2)) {
			while (sz(up) >= 2 && !cw(up[sz(up) - 2] ,up[sz(up) - 1], a[i]))
				up.pop_back();
			up.pb(a[i]);
		}
		if (i == sz(a) - 1 || ccw(p1, a[i], p2)) {
			while (sz(down) >= 2 && !ccw(down[sz(down) - 2], down[sz(down) - 1], a[i]))
				down.pop_back();
			down.pb(a[i]);
		}
	}
	a.clear();
	for (int i = 0; i < sz(up); i++)
		a.pb(up[i]);
	for (int i = sz(down) - 2; i > 0; i--)
		a.pb(down[i]);
}

bool isInside (Point a, Point b, Point c) {
	return (a.x <= b.x && b.x <= c.x && a.y <= b.y && b.y <= c.y);
}

double f (Point a, Point b, Point c) {
	return a.x*(b.y - c.y) + b.x*(c.y - a.y) + c.x*(a.y - b.y);
}

void convex_hull_jarvis(vector <Point> & a) {
	if (a.size() == 1) return;
	sort(all(a), cmp);

	vector <Point> hull;
	Point p0 = a[0];
	hull.pb(p0);

	int first = 0, cur = 0;
	do {
		int next = (cur + 1) % (sz(a));
		for (int i = 0; i < sz(a); i++) {
			int sign = f(a[cur], a[next], a[i]);
			if (is_less(sign, 0))
				next = i;
			else if (is_equal(sign, 0)) {
				if (isInside(a[cur], a[next], a[i]))
					next = i;
			}
		}
		cur = next;
		hull.pb(a[next]);
	}
	while (cur != first);
	a = hull;
	
}

int main() {
#ifdef _MBCS
	freopen("input.txt", "r", stdin);
	freopen("output.txt", "w", stdout);
#endif
	int n;
	scanf("%d", &n);
	vector <Point> points(n);
	for (int i = 0; i < n; i++) {
		points[i].scan();
		points[i].pos = i;
	}
	vector <int> id(n, -1);

	set <Point> s (all(points));
	for (int cnt = 1; sz(s); cnt++) {

		vector <Point> a (all(s));
		convex_hull_jarvis(a);
		for (int i = 0; i < sz(a); i++) {
			s.erase(a[i]);
			id[a[i].pos] = cnt;
		}
	}
	for (int i = 0; i < n; i++)
		printf("%d\n", id[i]);
	return 0;
}