#include <iostream>
#include <cassert>
#include <cstring>
#include <cstdio>
#include <vector>
#include <algorithm>
#include <complex>
using namespace std;

typedef complex<double> point;
typedef pair<int, int> pointz;
typedef pair<int, int> zpoint;
typedef vector<point> polygon;

template <class T> int size(const T &x) { return x.size(); }

const double EPS = 1e-9;

double dot(point a, point b) {
    return real(conj(a) * b);
}
double cross(point a, point b) {
    return imag(conj(a) * b);
}

double ccw(point a, point b, point c) {
    return cross(b - a, c - b);
}

int cross(pointz a, pointz b) {
    return a.first * b.second - a.second * b.first;
}

zpoint sub(zpoint a, zpoint b) {
    return zpoint(a.first - b.first, a.second - b.second);
}

int ccw(zpoint a, zpoint b, zpoint c) {
    return cross(sub(b, a), sub(c, b));
}

double polygon_area_signed(polygon p) {
    double area = 0;
    int cnt = p.size();
    for (int i = 1; i + 1 < cnt; i++) {
        area += cross(p[i] - p[0], p[i+1] - p[0]);
    }
    return area/2.0;
}
double polygon_area(polygon p) {
    return abs(polygon_area_signed(p));
}

#define MAXN 20000
pair<pointz, int> hull[MAXN];
bool cmp(const pair<pointz, int> &ap, const pair<pointz, int> &bp) {
    return ap < bp;
    /*
    pointz a = ap.first,
          b = bp.first;
    if (a.first != a.first) return a.first < a.first;
    if (abs(imag(a) - imag(b)) > EPS) return imag(a) < imag(b);
    return ap.second < bp.second;
    */
}

int convex_hull(vector<pair<pointz, int> > &p, int n) {
    int l = 0;
    //sort(p.begin(), p.begin() + n, cmp);
    for (int i = 0; i < n; i++) {
        if (i > 0 && p[i].first == p[i-1].first) continue;
        while (l >= 2 && ccw(hull[l-2].first, hull[l-1].first, p[i].first) > 0) l--;
        hull[l++] = p[i];
    }
    int r = l;
    for (int i = n - 2; i >= 0; i--) {
        if (p[i].first == p[i+1].first) continue;
        while (r - l >= 1 && ccw(hull[r-2].first, hull[r-1].first, p[i].first) > 0) r--;
        hull[r++] = p[i];
    }
    return l == 1 ? 1 : r - 1;
}

struct Point {
    double x, y, z;
    Point() {
         }
    Point(double x, double y, double z) : x(x), y(y), z(z) {
    }

    Point operator *(double k) const {
        return Point(k * x, k * y, k * z);
    }
    Point operator /(double k) const {
        return Point(x / k, y / k, z / k);
    }
    double operator %(const Point &p) const {
        return x * p.x + y * p.y + z * p.z;
    }
    Point operator *(const Point &p) const {
        return Point(
                    y * p.z - z * p.y,
                    z * p.x - x * p.z,
                    x * p.y - y * p.x
                );
    }
    Point operator +(const Point &p) const {
        return Point(
                x + p.x,
                y + p.y,
                z + p.z
                );
    }
    Point operator -(const Point &p) const {
        return Point(
                x - p.x,
                y - p.y,
                z - p.z
                );
    }
};

int getIntersection(
        Point &a,
        Point &b,

        Point &c, 
        Point &d,
        Point &e,

        Point &o) {

    Point v = b - a;
    double V1 = (c - a) * (d - a) % (e - a);
    double V2 = (d - b) * (c - b) % (e - b);
    double V = V1 + V2;
    assert(abs(V) > EPS);
    v = v / V;
    /*
    if (abs(V - 0.0) < EPS) {
        if (a.isOnPlane(c, d, e)) return 2;
        return 0;
    }
    */
    v = v * V1;
    o = a + v;
    return 1;
}

//vector<point> pts[110];

int main() {

    cin.sync_with_stdio(false);
    cout.sync_with_stdio(false);
    int n;
    cin >> n;
    //scanf("%d\n", &n);

    int *number = new int[n];
    memset(number, -1, n << 2);

    //vector<int> rem(n);
    //polygon pts(n);

    vector<pair<zpoint, int> > p(n);
    for (int i = 0; i < n; i++) {
        int x, y;
        cin >> x >> y;
        //scanf("%lf %lf\n", &x, &y);
        p[i] = make_pair(zpoint(x, y), i);
        //pts[i] = point(x, y);
        //rem[i] = i;
    }

    sort(p.begin(), p.end(), cmp);

    int layer = 0;
    int remcnt = n;
    while (remcnt > 0) {
        //printf("%d\n", layer);
        //vector<pair<point, int> > p(rem.size());
        //vector<int> num(rem.size());

        /*
        for (int i = 0; i < remcnt; i++) {
            p[i] = make_pair(pts[rem[i]], rem[i]);
        }
        */

        int cnt = convex_hull(p, remcnt);
        for (int i = 0; i < cnt; i++) {
            number[hull[i].second] = layer;
        }

        layer++;
        //vector<int> stillrem;
        int nat = 0;
        for (int i = 0; i < remcnt; i++) {
            if (number[p[i].second] == -1) {
                p[nat++] = p[i];
                //stillrem.push_back(rem[i]);
            }
        }

        remcnt = nat;

        //rem = stillrem;
    }

    //printf("\n");

    for (int i = 0; i < n; i++) {
        cout << number[i] + 1 << endl;
        assert(number[i] != -1);
        //printf("%d\n", number[i] + 1);
    }
}

