#include <iostream>
#include <climits>
#include <complex>
#include <algorithm>

using namespace std;

typedef long long int Z;
typedef complex<Z> V;

int N;
V pos[20005];
int polyidx[20005];

int points[20005];
int pleft;

int hull[20005];

bool ccw(V a, V b, V c) {
	return ((c - a) * conj(b - a)).imag() > 0;
}

void andrewize(int idx) {
	if(pleft <= 2) {
		for(int i = 0; i < pleft; ++i) {
			polyidx[points[i]] = idx;
		}
		pleft = 0;
		return;
	}
	
	int hulli = 1;
	hull[0] = points[0];
	for(int i = 1; i < pleft; ++i) {
		while(hulli >= 2 && !ccw(pos[hull[hulli - 2]], pos[hull[hulli - 1]], pos[points[i]])) --hulli;
		hull[hulli++] = points[i];
	}
	for(int i = 0; i < hulli; ++i) {
//		cout << idx << ": " << hull[i] << "\n";
		polyidx[hull[i]] = idx;
	}
	
	hulli = 1;
	hull[0] = points[pleft - 1];
	for(int i = pleft - 2; i >= 0; --i) {
		while(hulli >= 2 && !ccw(pos[hull[hulli - 2]], pos[hull[hulli - 1]], pos[points[i]])) --hulli;
		hull[hulli++] = points[i];
	}
	for(int i = 0; i < hulli; ++i) {
//		cout << idx << ": " << hull[i] << "\n";
		polyidx[hull[i]] = idx;
	}
	
	int j = 0;
	for(int i = 0; i < pleft; ++i) {
		if(!polyidx[points[i]]) points[j++] = points[i];
	}
	pleft = j;
}

int main() {
	cin.sync_with_stdio(false);
	cin >> N;
	for(int i = 0; i < N; ++i) {
		Z x, y;
		cin >> x >> y;
		pos[i] = V(x, y);
	}
	
	pleft = N;
	for(int i = 0; i < N; ++i) {
		points[i] = i;
	}
	sort(
		points, points + pleft,
		[](int a, int b) {
			return make_pair(pos[a].real(), pos[a].imag()) < make_pair(pos[b].real(), pos[b].imag());
		}
	);
	
	int idx = 1;
	while(pleft) {
		andrewize(idx++);
	}
	
	for(int i = 0; i < N; ++i) {
		cout << polyidx[i] << "\n";
	}
	
	return 0;
}
