#include <cmath>
#include <iostream>
#include <cstdio>

using namespace std;

double sqr( double a )
{
	return a*a;
}


bool Equal ( double a, double b)
{
	return fabs( a-b) < 1e-9;
}


bool LessOrEqual (double a, double b)
{
	return a<b || Equal(a, b);
}


bool Less (double a, double b)
{
	return a < b && !Equal (a, b);
}


bool GreaterOrEqual ( double a, double b)
{
	return a > b || Equal (a, b);
}


bool Greater (double a, double b)
{
	return a > b && !Equal (a,b);
}


double mySqrt (double a)
{
	if ( Less (a,0))
	{
		throw "sqrt(-1)";
	}
	if (a < 0) return 0;
	return sqrt(a);
}


struct Point {

private: double x,y;
public:
	Point() : x(0), y(0) {}

	Point(double x, double y) : x(x), y(y) {}

	void scan() {
		scanf("%lf %lf", &x, &y);
	}

	void print() const {
		printf("%.10lf %.10lf\n", x, y);
	}

	Point operator+ (const Point & p) const {
		return Point(x + p.x, y + p.y);
	}

	Point operator- (const Point & p) const {
		return Point(x - p.x, y - p.y);
	}

	Point operator-() const {
		return Point(-x, -y);
	}
	Point operator* (double k) {
		return Point(x * k, y * k);
	}
	Point operator/ (double k) {
		return Point(x / k, y / k);
	}
	double operator% (const Point & p) const {
		return x * p.x + y * p.y;
	}
	double operator* (const Point & p) const {
		return x * p.y - y * p.x;
	}
	bool operator== (const Point & p) const {
		return (Equal(x, p.x) && Equal(y, p.y));
	}
	double length() const {
		return mySqrt(*this % *this);
	}
	double distTo (const Point & p) const {
		return (*this - p).length();
	}

	double distTo (const Point & A, Point & B) const {
		double d = A.distTo(B);
		if (Equal(d, 0)) {
			throw "A = B";
		}
		double s = (*this - A) * (*this - B);
		return fabs(s) / d;
	}

	bool isOnline (const Point & A, const Point & B) const {
		return Equal((A - *this) * (B - *this), 0);
	}

	bool isinSegment (const Point & A, const Point & B) const {
		return isOnline(A, B) && LessOrEqual( (A - *this) % (B - *this) , 0);
	}

};

int getIntersection 
		(
			const Point & A,
			const Point & B,
			const Point & C,
			const Point & D,
			Point & O
		)
{
	{
		Point v = B - A;
		double s1 = (C - A) * (D - A);
		double s2 = (D - B) * (C - B);
		double s = s1 + s2;
		if (Equal(s, 0)) {
			if (!A.isOnline (C, D)) {
				return 0;
			}
			return 2;
		}
		v = v / s;
		v = v * s1;
		O = A + v;
		return 1;
	}
}

Point F;
Point O (0, 0);
double sum = 0;

double step (Point & A, Point & B, Point & C) {
	double S = fabs( (C - B) * (A - B) / 2 );
	if (Less(S, 0.001)) return 0;
	Point H = (A + C) / 2;
	double Clen = C.distTo(F);
	double Alen = A.distTo(F);
	if (Equal(Clen, Alen)) {
		sum += S / 2;
		return S;
	}
	if (Less(Clen, Alen)) {
		Point OB;
		int cnt = 0;
		if (getIntersection(H, A, O, F, OB) == 1) {
			if (!(OB == H) && (OB.isinSegment(A, H)) && OB.isinSegment(O, F))
				++cnt;
		}
		if (getIntersection(A, B, O, F, OB) == 1) {
			if (!(OB == A) && (OB.isinSegment(A, B)) && OB.isinSegment(O, F))
				++cnt;
		}
		if (getIntersection(B, H, O, F, OB) == 1) {
			if (!(OB == B) && (OB.isinSegment(B, H)) && OB.isinSegment(O, F))
				++cnt;
		}
		if (cnt == 2) {
			sum += S / 2;
			return (S / 2) + step(B, H, C);
		}
		else
			return step(B, H, C);
	}
	else {
		Point OB;
		int cnt = 0;
		if (getIntersection(B, H, O, F, OB) == 1) {
			if (!(OB == B) && (OB.isinSegment(B, H)) && OB.isinSegment(O, F))
				++cnt;
		}
		if (getIntersection(H, C, O, F, OB) == 1) {
			if (!(OB == H) && (OB.isinSegment(H, C)) && OB.isinSegment(O, F))
				++cnt;
		}
		if (getIntersection(C, B, O, F, OB) == 1) {
			if (!(OB == C) && (OB.isinSegment(C, B)) && OB.isinSegment(O, F))
				++cnt;
		}
		if (cnt == 2) {
			sum += S / 2;
			return (S / 2) + step(B, H, C);
		}
		else
			return step(A, H, B);
	}
}


int main () {
#ifdef _DEBUG
	freopen("input.txt", "r", stdin);
	freopen("output.txt", "w", stdout);
#endif
	F.scan();
	Point A(0, 0);
	Point B(10, 0);
	Point C(10, 10);
	double ans = step(A, B, C);
	printf("%.3lf", ans);
	return 0;
}
