#include <iostream>
#include <algorithm>
#include <set>
#include <map>
#include <string>
#include <cstdio>
#include <ctime>
#include <cassert>
#include <vector>
#include <queue>
#include <cmath>

#define fr first
#define sc second
#define mp make_pair
#define pb push_back 

using namespace std;

const int N = 1e5;
const int INF = 1e9;
const double eps9 = 1e-9;

bool equal(double a, double b) {
	return abs(a - b) < eps9;
}

struct pnt3 {
	double x, y, z;
	pnt3() { }
	pnt3(double x, double y, double z): x(x), y(y), z(z) { }
	pnt3 operator - (pnt3 A) {
		return pnt3(x - A.x, y - A.y, z - A.z);
	}
	pnt3 operator + (pnt3 A) {
		return pnt3(x + A.x, y + A.y, z + A.z);
	}
	pnt3 operator * (double k) {
		return pnt3(x * k, y * k, z * k);
	}
	void read() {
		scanf("%lf%lf%lf", &x, &y, &z);
	}
};

struct pnt2 {
	double x, y;
	pnt2() { }
	pnt2(double x, double y): x(x), y(y) { }
	pnt2 operator - (pnt2 A) {
		return pnt2(x - A.x, y - A.y);
	}
	double operator * (pnt2 A) {
		return x * A.y - y * A.x;
	}
	double len() {
		return sqrt(x * x + y * y);
	}
};

pnt3 p[N];
pnt2 stack[N];
pnt2 O;

bool cmpZ(pnt3 a, pnt3 b) {
	return a.z < b.z;
}

bool cmp(pnt2 a, pnt2 b) {
	return (a - O) * (b - O) > 0 || (equal((a - O) * (b - O), 0) && (a - O).len() < (b - O).len());	
}

vector < pnt2 > convexHull(vector < pnt2 > & b) {
	int n = b.size();
	for (int i = 0; i < n; i++)
		if (b[i].y < b[0].y || (b[i].y == b[0].y && b[i].x < b[0].x))
			swap(b[i], b[0]); 
	O = b[0];
	sort(b.begin(), b.end(), cmp);
	int cur = 0;
	for (int i = 0; i < n; i++) {
		for (; cur >= 2 && (stack[cur - 1] - stack[cur - 2]) * (b[i] - stack[cur - 1]) <= 0 ; cur--);	
		stack[cur++] = b[i];
	}
	vector < pnt2 > t;
	for (int i = 0; i < cur; i++)
		t.pb(stack[i]);
	return t;
}

double getS(vector < pnt2 > & b) {
	double ans = 0;
	for (int i = 0; i < (int)b.size(); i++) 
		ans += (b[i] * b[(i + 1) % b.size()]);
	return ans / 2;
}

int main() {
#ifdef DEBUG
	freopen("in", "r", stdin);
#endif
	int n, zMin, zMax;
	scanf("%d%d%d", &n, &zMin, &zMax);
	for (int i = 0; i < n; i++) {
		p[i].read();
	}
	sort(p, p + n, cmpZ);
	for (int z = zMin; z <= zMax; z++) {
		vector < pnt3 > b;
		for (int i = 0; i < n; i++)
			if (equal(p[i].z, z)) 
				b.pb(p[i]);
		for (int i = 0; i < n; i++)
			for (int j = i + 1; j < n; j++) {
				if (p[i].z < z && z < p[j].z) {
					pnt3 v = p[j] - p[i];		
					double dz = z - p[i].z;
					double k = dz / (p[j].z - p[i].z);
					v = v * k;
					b.pb(p[i] + v);
				}
			}
		vector < pnt2 > a;
		for (auto p: b) 
			a.pb(pnt2(p.x, p.y));
		auto t = convexHull(a);
		double s = getS(t);
		printf("%.15lf\n", s);
	}
	return 0;
}

